"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.udpCommunication = void 0;
const vscode = __importStar(require("vscode"));
const terminal_1 = require("./terminal");
const os_1 = __importDefault(require("os"));
const dgram_1 = __importDefault(require("dgram"));
var UdpMessageStatus;
(function (UdpMessageStatus) {
    UdpMessageStatus[UdpMessageStatus["MessageNeverReceived"] = 0] = "MessageNeverReceived";
    UdpMessageStatus[UdpMessageStatus["MessageReceiveTimeout"] = 1] = "MessageReceiveTimeout";
    UdpMessageStatus[UdpMessageStatus["MessageReceiveNormal"] = 2] = "MessageReceiveNormal";
})(UdpMessageStatus || (UdpMessageStatus = {}));
class udpCommunication {
    constructor(arduinoContext) {
        this.arduinoContext = arduinoContext;
        this.remoteAddress = undefined;
        this.remotePort = undefined;
        this.server = dgram_1.default.createSocket("udp4");
        this.messageStatus = UdpMessageStatus.MessageNeverReceived;
        this.arduinoContext.onDidChange('port')((port) => {
            // vscode.window.showInformationMessage(`port: ${port?.address} ${port?.hardwareId} ${port?.label} ${port?.properties} ${port?.protocol} ${port?.protocolLabel}`)
            this.portChangeMonitor(port);
        });
        this.arduinoContext.onDidChange('fqbn')((fqbn) => {
            this.portChangeMonitor(arduinoContext.port);
        });
        this.createUDPServer();
        var interval = setInterval(() => {
            if (this.messageStatus !== UdpMessageStatus.MessageReceiveNormal) {
                if (this.remotePort !== undefined && this.remoteAddress !== undefined) {
                    this.server.send('~arduino-network-monitor', this.remotePort, this.remoteAddress);
                }
            }
            this.messageStatus = UdpMessageStatus.MessageReceiveTimeout;
        }, 6000);
        this.portChangeMonitor(arduinoContext.port);
        vscode.window.onDidCloseTerminal(t => {
            if (t.exitStatus && t.exitStatus.code) {
                //   vscode.window.showErrorMessage(`Exit code: ${t.exitStatus.code}`);
            }
        });
        this.toDispose = [
            new vscode.Disposable(() => {
                // vscode.window.showInformationMessage( 'clearInterval');
                clearInterval(interval);
                this.abortController?.abort();
            })
        ];
        terminal_1.channel.subscribe((message) => {
            const typedMessage = message;
            vscode.window.showInformationMessage("send: " + typedMessage.message);
            this.server.send('' + typedMessage.message, this.remotePort, this.remoteAddress);
        });
    }
    getIPV4Address(routeMatch) {
        const interfaces = os_1.default.networkInterfaces();
        for (const devName in interfaces) {
            console.log(devName);
            const iface = interfaces[devName];
            console.log(iface);
            for (let i = 0; ((iface !== undefined) && (i < iface.length)); i++) {
                let alias = iface[i];
                console.log(alias);
                if (alias.family === 'IPv4' && alias.address !== '127.0.0.1' && !alias.internal) {
                    if (alias.address.indexOf(routeMatch.slice(0, 9)) !== -1) {
                        // vscode.window.showInformationMessage("IP:" +alias.address);
                        return alias.address;
                    }
                    // vscode.window.showInformationMessage(routeMatch + ' '+alias.address.indexOf(routeMatch));
                }
            }
        }
        return undefined;
    }
    portChangeMonitor(port) {
        this.remoteAddress = port?.address;
        for (const key in port?.properties) {
            if (key === 'udp_port') {
                this.remotePort = parseInt(port.properties[key], 10);
            }
            // vscode.window.showInformationMessage(key +' '+ port.properties[key]);
        }
        if (port?.protocol != "network") {
            this.remotePort = undefined;
            // vscode.window.showInformationMessage( port?.protocol+'');
        }
        if (this.remoteAddress !== undefined) {
            this.closeUDPServer();
            this.createUDPServer();
        }
    }
    createUDPServer() {
        this.server = dgram_1.default.createSocket("udp4");
        // vscode.window.showInformationMessage('createUDPServer');
        this.server.on("message", (msg, rinfo) => {
            this.messageStatus = UdpMessageStatus.MessageReceiveNormal;
            (0, terminal_1.showMessageToTerminal)(msg.toString());
        });
        this.server.on("listening", () => {
            // vscode.window.showInformationMessage("address:" + this.server.address().address);
            // vscode.window.showInformationMessage("port:" + this.server.address().port);
            setTimeout(() => {
                (0, terminal_1.showMessageToTerminal)("listening address:" + this.server.address().address + '\r\n');
            }, 600);
            setTimeout(() => {
                (0, terminal_1.showMessageToTerminal)("listening port:" + this.server.address().port + '\r\n');
            }, 600);
        });
        this.server.on('error', (err) => {
            vscode.window.showErrorMessage(`server error:\n${err.stack}`);
            this.server.close();
        });
        if (this.remoteAddress !== undefined) {
            this.server.bind(0, this.getIPV4Address(this.remoteAddress));
        }
        else {
            this.server.bind(0);
        }
    }
    // 关闭UDP服务器
    closeUDPServer() {
        if (this.server) {
            this.server?.close(() => {
                // vscode.window.showInformationMessage('UDP Server closed');
            });
        }
    }
}
exports.udpCommunication = udpCommunication;
//# sourceMappingURL=udp-server.js.map